# Generated by roxygen2: do not edit by hand

S3method(anova,survey_glm_fit)
S3method(meta,survey_result)
S3method(print,survey_anova)
S3method(print,survey_diffs)
S3method(print,survey_effective_n)
S3method(print,survey_pairwise)
S3method(print,survey_result)
S3method(print,survey_t_test)
export(.get_design_vars_flat)
export(SURVEYCORE_DOMAIN_COL)
export(add_survey)
export(as_caldata)
export(as_survey)
export(as_survey_collection)
export(as_survey_nonprob)
export(as_survey_replicate)
export(as_survey_twophase)
export(as_svydesign)
export(as_tbl_svy)
export(classify_question_type)
export(clean)
export(extract_higher_is)
export(extract_metadata)
export(extract_missing_codes)
export(extract_question_preface)
export(extract_reverse_coded)
export(extract_sata)
export(extract_universe)
export(extract_val_labels)
export(extract_var_label)
export(extract_var_note)
export(from_svydesign)
export(from_tbl_svy)
export(get_anova)
export(get_corr)
export(get_covariance)
export(get_diffs)
export(get_effective_n)
export(get_freqs)
export(get_means)
export(get_pairwise)
export(get_quantiles)
export(get_ratios)
export(get_t_test)
export(get_totals)
export(get_variance)
export(infer_question_prefaces)
export(meta)
export(remove_survey)
export(set_collection_id)
export(set_collection_if_missing_var)
export(set_higher_is)
export(set_missing_codes)
export(set_question_preface)
export(set_reverse_coded)
export(set_sata)
export(set_universe)
export(set_val_labels)
export(set_var_label)
export(set_var_note)
export(survey_base)
export(survey_collection)
export(survey_data)
export(survey_glm)
export(survey_glm_fit)
export(survey_metadata)
export(survey_nonprob)
export(survey_replicate)
export(survey_taylor)
export(survey_twophase)
export(survey_weighting_history)
export(update_design)
