# survey_weighting_history() errors for non-survey-object input

    Code
      survey_weighting_history(42)
    Condition
      Error in `survey_weighting_history()`:
      x `x` must be a survey design object.
      i Got <numeric>.

