# infer_question_prefaces() rejects non-survey non-data-frame input

    Code
      infer_question_prefaces(list(x = 1))
    Condition
      Error in `infer_question_prefaces()`:
      x `x` must be a survey design object or a data frame, not <list>.

