% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\docType{data}
\name{SURVEYCORE_DOMAIN_COL}
\alias{SURVEYCORE_DOMAIN_COL}
\title{Internal Domain Column Name Constant}
\format{
An object of class \code{character} of length 1.
}
\usage{
SURVEYCORE_DOMAIN_COL
}
\description{
The name of the logical column added to \verb{@data} by \code{filter()} (from
\code{surveytidy}) to mark domain membership. Exposed here so that sibling
packages (\code{surveytidy}, \code{surveywts}) can reference it without
using \code{:::}.
}
\keyword{internal}
