% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{survey_weighting_history}
\alias{survey_weighting_history}
\title{Extract the Weighting History from a Survey Object}
\usage{
survey_weighting_history(x)
}
\arguments{
\item{x}{A survey design object (any class inheriting from \code{survey_base}).}
}
\value{
A \code{list} of history entries, or \code{list()} if no history is present.
}
\description{
Returns the list of weighting operations recorded on a survey design object.
Each entry is appended by surveywts after a calibration or nonresponse
adjustment step. Returns an empty list when no history has been recorded.
}
\examples{
d <- as_survey(nhanes_2017, ids = sdmvpsu, weights = wtint2yr,
               strata = sdmvstra, nest = TRUE)
survey_weighting_history(d)   # list() — no weighting history

}
\seealso{
Other metadata: 
\code{\link{classify_question_type}()},
\code{\link{extract_metadata}()},
\code{\link{extract_missing_codes}()},
\code{\link{extract_question_preface}()},
\code{\link{extract_sata}()},
\code{\link{extract_universe}()},
\code{\link{extract_val_labels}()},
\code{\link{extract_var_label}()},
\code{\link{extract_var_note}()},
\code{\link{infer_question_prefaces}()},
\code{\link{set_missing_codes}()},
\code{\link{set_question_preface}()},
\code{\link{set_sata}()},
\code{\link{set_universe}()},
\code{\link{set_val_labels}()},
\code{\link{set_var_label}()},
\code{\link{set_var_note}()},
\code{\link{survey_metadata}()}
}
\concept{metadata}
